@@ -30,7 +30,7 @@ def remove_from_slack(options: GlobalOptions, integration_id: str) -> None:
 
 def slack_uninstall(api_url: str, integration_id: str):
     try:
-        url = f"{api_url}uninstall/slack/"
+        url = f"{api_url}/uninstall/slack/"
         response = requests.get(
             url,
             headers={"Authorization": get_auth_header()},
