@@ -19,3 +19,10 @@ class InvalidTokenError(CliError):
 class NotAuthorizedError(CliError):
     def __init__(self) -> None:
         super().__init__(f"Please run `symflow login`")
+
+
+class SymAPIUnknownError(CliError):
+    def __init__(self, response_code: int, request_id: str) -> None:
+        super().__init__(
+            f"Sym API request failed.\nStatus Code: {response_code}\nRequest ID: {request_id}"
+        )
