@@ -8,6 +8,7 @@ import click
 import pkce
 import requests
 
+from sym.cli.errors import CliError
 from sym.flow.cli.helpers.constants import DEFAULT_SCOPES
 from sym.flow.cli.helpers.login.handler import make_handler
 
@@ -93,6 +94,8 @@ class BrowserRedirectFlow(LoginFlow):
 
     def login(self, options: GlobalOptions, org: Organization) -> AuthToken:
         auth_code, code_verifier = self.get_auth_code(options, org)
+        if not auth_code:
+            raise CliError("Unable to get access token from Auth0. Please try again.")
         return self.get_token_from_code(options, org, auth_code, code_verifier)
 
     @property
@@ -107,7 +110,7 @@ class BrowserRedirectFlow(LoginFlow):
         httpd = HTTPServer(("localhost", self.port), handler)
         options.dprint(f"Waiting for an auth code at {self.redirect_url}")
         httpd.handle_request()
-        return handler.auth_code
+        return getattr(handler, "auth_code", None)
 
     def gen_state(self) -> str:
         return str(uuid.uuid4())
